@@ -19,16 +19,18 @@ package org.apache.maven.plugin.javadoc;
  * under the License.
  */
 
+import org.apache.maven.plugins.annotations.Mojo;
+import org.apache.maven.plugins.annotations.ResolutionScope;
+
 /**
  * Generates documentation for the <code>Java code</code> in an <b>aggregator</b> project using the standard
- * <a href="http://java.sun.com/j2se/javadoc/">Javadoc Tool</a>.
+ * <a href="http://docs.oracle.com/javase/7/docs/technotes/guides/javadoc/">Javadoc Tool</a>.
  *
  * @author <a href="mailto:vincent.siveton@gmail.com">Vincent Siveton</a>
- * @version $Id: AggregatorJavadocReport.java 1054423 2011-01-02 16:12:18Z hboutemy $
- * @goal aggregate
- * @aggregator
+ * @version $Id: AggregatorJavadocReport.java 1385191 2012-09-15 22:04:49Z hboutemy $
  * @since 2.5
  */
+@Mojo( name = "aggregate", aggregator = true, requiresDependencyResolution = ResolutionScope.COMPILE )
 public class AggregatorJavadocReport
     extends JavadocReport
 {
