@@ -19,16 +19,19 @@ package org.apache.maven.plugin.javadoc;
  * under the License.
  */
 
+import org.apache.maven.plugins.annotations.LifecyclePhase;
+import org.apache.maven.plugins.annotations.Mojo;
+import org.apache.maven.plugins.annotations.ResolutionScope;
+
 /**
  * Bundles the Javadoc documentation for <code>Java Test code</code> in an <b>aggregator</b> project into a jar
- * using the standard <a href="http://java.sun.com/j2se/javadoc/">Javadoc Tool</a>.
+ * using the standard <a href="http://docs.oracle.com/javase/7/docs/technotes/guides/javadoc/">Javadoc Tool</a>.
  *
- * @version $Id: AggregatorTestJavadocJar.java 1054423 2011-01-02 16:12:18Z hboutemy $
+ * @version $Id: AggregatorTestJavadocJar.java 1385191 2012-09-15 22:04:49Z hboutemy $
  * @since 2.6
- * @goal test-aggregate-jar
- * @phase package
- * @aggregator
  */
+@Mojo( name = "test-aggregate-jar", defaultPhase = LifecyclePhase.PACKAGE, aggregator = true,
+       requiresDependencyResolution = ResolutionScope.TEST )
 public class AggregatorTestJavadocJar
     extends TestJavadocJar
 {
