@@ -95,7 +95,7 @@ import java.util.regex.PatternSyntaxException;
  * Set of utilities methods for Javadoc.
  *
  * @author <a href="mailto:vincent.siveton@gmail.com">Vincent Siveton</a>
- * @version $Id: JavadocUtil.java 1463966 2013-04-03 12:40:40Z olamy $
+ * @version $Id: JavadocUtil.java 1672205 2015-04-08 22:10:02Z khmarbaise $
  * @since 2.4
  */
 public class JavadocUtil
@@ -166,6 +166,9 @@ public class JavadocUtil
     /**
      * Determine whether a file should be excluded from the provided list of paths, based on whether
      * it exists and is already present in the list.
+     * @param f The files.
+     * @param pruned The list of pruned files..
+     * @return true if the file could be pruned false otherwise.
      */
     public static boolean shouldPruneFile( String f, List<String> pruned )
     {
@@ -196,7 +199,7 @@ public class JavadocUtil
         List<String> excludedNames = new ArrayList<String>();
         for ( String path : sourcePaths )
         {
-            for ( int j = 0; j < subpackagesList.length; j++ )
+            for ( String aSubpackagesList : subpackagesList )
             {
                 List<String> excludes = getExcludedPackages( path, excludedPackages );
                 excludedNames.addAll( excludes );
@@ -272,7 +275,7 @@ public class JavadocUtil
 
         if ( StringUtils.isNotEmpty( arg ) )
         {
-            if ( arg.indexOf( "'" ) != -1 )
+            if ( arg.contains( "'" ) )
             {
                 arg = StringUtils.replace( arg, "'", "\\'" );
             }
@@ -299,7 +302,7 @@ public class JavadocUtil
         if ( StringUtils.isNotEmpty( path ) )
         {
             path = path.replace( '\\', '/' );
-            if ( path.indexOf( "\'" ) != -1 )
+            if ( path.contains( "\'" ) )
             {
                 String split[] = path.split( "\'" );
                 path = "";
@@ -409,7 +412,7 @@ public class JavadocUtil
     {
         List<String> files = new ArrayList<String>();
 
-        for ( int j = 0; j < fileList.length; j++ )
+        for ( String aFileList : fileList )
         {
             boolean include = true;
             for ( int k = 0; k < excludePackages.length && include; k++ )
@@ -427,7 +430,7 @@ public class JavadocUtil
                     int u = 0;
                     while ( include && u < excludeName.length )
                     {
-                        if ( !"".equals( excludeName[u].trim() ) && fileList[j].indexOf( excludeName[u] ) != -1 )
+                        if ( !"".equals( excludeName[u].trim() ) && aFileList.contains( excludeName[u] ) )
                         {
                             include = false;
                         }
@@ -436,16 +439,16 @@ public class JavadocUtil
                 }
                 else
                 {
-                    if ( fileList[j].startsWith( sourceDirectory.toString() + File.separatorChar + excludeName[0] ) )
+                    if ( aFileList.startsWith( sourceDirectory.toString() + File.separatorChar + excludeName[0] ) )
                     {
                         if ( excludeName[0].endsWith( String.valueOf( File.separatorChar ) ) )
                         {
-                            int i = fileList[j].lastIndexOf( File.separatorChar );
-                            String packageName = fileList[j].substring( 0, i + 1 );
+                            int i = aFileList.lastIndexOf( File.separatorChar );
+                            String packageName = aFileList.substring( 0, i + 1 );
                             File currentPackage = new File( packageName );
                             File excludedPackage = new File( sourceDirectory, excludeName[0] );
                             if ( currentPackage.equals( excludedPackage )
-                                && fileList[j].substring( i ).indexOf( ".java" ) != -1 )
+                                && aFileList.substring( i ).contains( ".java" ) )
                             {
                                 include = true;
                             }
@@ -464,7 +467,7 @@ public class JavadocUtil
 
             if ( include )
             {
-                files.add( quotedPathArgument( fileList[j] ) );
+                files.add( quotedPathArgument( aFileList ) );
             }
         }
 
@@ -482,19 +485,19 @@ public class JavadocUtil
     protected static List<String> getExcludedPackages( String sourceDirectory, String[] excludePackagenames )
     {
         List<String> files = new ArrayList<String>();
-        for ( int i = 0; i < excludePackagenames.length; i++ )
+        for ( String excludePackagename : excludePackagenames )
         {
             String[] fileList = FileUtils.getFilesFromExtension( sourceDirectory, new String[] { "java" } );
-            for ( int j = 0; j < fileList.length; j++ )
+            for ( String aFileList : fileList )
             {
-                String[] excludeName = excludePackagenames[i].split( "[*]" );
+                String[] excludeName = excludePackagename.split( "[*]" );
                 int u = 0;
                 while ( u < excludeName.length )
                 {
-                    if ( !"".equals( excludeName[u].trim() ) && fileList[j].indexOf( excludeName[u] ) != -1
-                        && sourceDirectory.indexOf( excludeName[u] ) == -1 )
+                    if ( !"".equals( excludeName[u].trim() ) && aFileList.contains( excludeName[u] )
+                        && !sourceDirectory.contains( excludeName[u] ) )
                     {
-                        files.add( fileList[j] );
+                        files.add( aFileList );
                     }
                     u++;
                 }
@@ -525,6 +528,8 @@ public class JavadocUtil
      * @param sourceDirectory the directory where the source files are located
      * @param files the variable that contains the appended filenames of the files to be included in the javadoc
      * @param excludePackages the packages to be excluded in the javadocs
+     * @param sourceFileIncludes files to include.
+     * @param sourceFileExcludes files to exclude.
      */
     protected static void addFilesFromSource( List<String> files, File sourceDirectory,
                                               List<String> sourceFileIncludes,
@@ -548,7 +553,7 @@ public class JavadocUtil
         String[] pathList = new String[fileList.length];
         for ( int x = 0; x < fileList.length; x++ )
         {
-            pathList[x] = new File( sourceDirectory, fileList[x] ).getAbsolutePath( );
+            pathList[x] = new File( sourceDirectory, fileList[x] ).getAbsolutePath();
         }
 
 
@@ -574,7 +579,7 @@ public class JavadocUtil
      * @see #parseJavadocVersion(String)
      */
     protected static float getJavadocVersion( File javadocExe )
-        throws IOException, CommandLineException, IllegalArgumentException, PatternSyntaxException
+        throws IOException, CommandLineException, IllegalArgumentException
     {
         if ( ( javadocExe == null ) || ( !javadocExe.exists() ) || ( !javadocExe.isFile() ) )
         {
@@ -653,7 +658,7 @@ public class JavadocUtil
      * @throws IllegalArgumentException if the output is null
      */
     protected static float parseJavadocVersion( String output )
-        throws IllegalArgumentException, PatternSyntaxException
+        throws IllegalArgumentException
     {
         if ( StringUtils.isEmpty( output ) )
         {
@@ -883,11 +888,11 @@ public class JavadocUtil
     {
         if ( file == null )
         {
-            throw new IOException( "The file " + file + " can't be null." );
+            throw new IOException( "The file can't be null." );
         }
         if ( url == null )
         {
-            throw new IOException( "The url " + url + " could not be null." );
+            throw new IOException( "The url could not be null." );
         }
 
         InputStream is = url.openStream();
@@ -1009,8 +1014,9 @@ public class JavadocUtil
             String invokerLogContent = readFile( invokerLog, "UTF-8" );
 
             // see DefaultMaven
-            if ( invokerLogContent != null && ( invokerLogContent.indexOf( "Scanning for projects..." ) == -1
-                || invokerLogContent.indexOf( OutOfMemoryError.class.getName() ) != -1 ) )
+            if ( invokerLogContent != null
+                && ( !invokerLogContent.contains( "Scanning for projects..." )
+                                || invokerLogContent.contains( OutOfMemoryError.class.getName() ) ) )
             {
                 if ( log != null )
                 {
@@ -1030,8 +1036,9 @@ public class JavadocUtil
             String invokerLogContent = readFile( invokerLog, "UTF-8" );
 
             // see DefaultMaven
-            if ( invokerLogContent != null && ( invokerLogContent.indexOf( "Scanning for projects..." ) == -1
-                || invokerLogContent.indexOf( OutOfMemoryError.class.getName() ) != -1 ) )
+            if ( invokerLogContent != null
+                && ( !invokerLogContent.contains( "Scanning for projects..." )
+                                || invokerLogContent.contains( OutOfMemoryError.class.getName() ) ) )
             {
                 throw new MavenInvocationException( ERROR_INIT_VM );
             }
@@ -1194,6 +1201,7 @@ public class JavadocUtil
             {
                 if ( !invokerLog.exists() )
                 {
+                    //noinspection ResultOfMethodCallIgnored
                     invokerLog.getParentFile().mkdirs();
                 }
                 os = new FileOutputStream( invokerLog );
@@ -1251,7 +1259,6 @@ public class JavadocUtil
         finally
         {
             IOUtil.close( os );
-            ps = null;
         }
     }
 
@@ -1453,12 +1460,8 @@ public class JavadocUtil
          */
         public boolean hasMoreTokens()
         {
-            if ( lookahead != null )
-            {
-                return true;
-            }
+            return lookahead != null || tokenizer.hasMoreTokens();
 
-            return tokenizer.hasMoreTokens();
         }
 
         /**
@@ -1472,7 +1475,7 @@ public class JavadocUtil
         public String nextToken()
             throws NoSuchElementException
         {
-            String token = null;
+            String token;
             if ( lookahead != null )
             {
                 token = lookahead;
@@ -1827,15 +1830,15 @@ public class JavadocUtil
             if ( StringUtils.isNotEmpty( activeProxy.getHost() )
                  && ( url == null || !ProxyUtils.validateNonProxyHosts( proxyInfo, url.getHost() ) ) )
             {
-                HttpHost proxy = new HttpHost(activeProxy.getHost(), activeProxy.getPort());
-                httpClient.getParams().setParameter(ConnRoutePNames.DEFAULT_PROXY, proxy);
+                HttpHost proxy = new HttpHost( activeProxy.getHost(), activeProxy.getPort() );
+                httpClient.getParams().setParameter( ConnRoutePNames.DEFAULT_PROXY, proxy );
 
                 if ( StringUtils.isNotEmpty( activeProxy.getUsername() ) && activeProxy.getPassword() != null )
                 {
                     Credentials credentials =
                         new UsernamePasswordCredentials( activeProxy.getUsername(), activeProxy.getPassword() );
 
-                    httpClient.getCredentialsProvider().setCredentials(AuthScope.ANY, credentials);
+                    httpClient.getCredentialsProvider().setCredentials( AuthScope.ANY, credentials );
                 }
             }
         }
