@@ -39,10 +39,11 @@ import java.util.List;
  * a jar using the standard <a href="http://docs.oracle.com/javase/7/docs/technotes/guides/javadoc/">Javadoc Tool</a>.
  *
  * @author <a href="mailto:vincent.siveton@gmail.com">Vincent Siveton</a>
- * @version $Id: TestJavadocJar.java 1438083 2013-01-24 17:20:31Z olamy $
+ * @version $Id: TestJavadocJar.java 1666819 2015-03-15 18:32:20Z khmarbaise $
  * @since 2.5
  */
-@Mojo( name = "test-jar", defaultPhase = LifecyclePhase.PACKAGE, requiresDependencyResolution = ResolutionScope.TEST, threadSafe = true)
+@Mojo( name = "test-jar", defaultPhase = LifecyclePhase.PACKAGE, requiresDependencyResolution = ResolutionScope.TEST,
+                threadSafe = true )
 public class TestJavadocJar
     extends JavadocJar
 {
@@ -53,7 +54,7 @@ public class TestJavadocJar
     /**
      * Specifies the destination directory where Javadoc saves the generated HTML files.
      * <br/>
-     * See <a href="http://docs.oracle.com/javase/1.4.2/docs/tooldocs/windows/javadoc.html#d">d</a>.
+     * See <a href="http://docs.oracle.com/javase/7/docs/technotes/tools/windows/javadoc.html#d">d</a>.
      * <br/>
      */
     @Parameter( defaultValue = "${project.build.directory}/testapidocs", required = true )
@@ -62,7 +63,7 @@ public class TestJavadocJar
     /**
      * Specifies the Test title to be placed near the top of the overview summary file.
      * <br/>
-     * See <a href="http://docs.oracle.com/javase/1.4.2/docs/tooldocs/windows/javadoc.html#doctitle">doctitle</a>.
+     * See <a href="http://docs.oracle.com/javase/7/docs/technotes/tools/windows/javadoc.html#doctitle">doctitle</a>.
      * <br/>
      *
      * @since 2.5
@@ -75,7 +76,7 @@ public class TestJavadocJar
      * Specifies that Javadoc should retrieve the text for the Test overview documentation from the "source" file
      * specified by path/filename and place it on the Overview page (overview-summary.html).
      * <br/>
-     * See <a href="http://docs.oracle.com/javase/1.4.2/docs/tooldocs/windows/javadoc.html#overview">overview</a>.
+     * See <a href="http://docs.oracle.com/javase/7/docs/technotes/tools/windows/javadoc.html#overview">overview</a>.
      * <br/>
      *
      * @since 2.5
@@ -87,7 +88,8 @@ public class TestJavadocJar
     /**
      * Specifies the Test title to be placed in the HTML title tag.
      * <br/>
-     * See <a href="http://docs.oracle.com/javase/1.4.2/docs/tooldocs/windows/javadoc.html#windowtitle">windowtitle</a>.
+     * See
+     * <a href="http://docs.oracle.com/javase/7/docs/technotes/tools/windows/javadoc.html#windowtitle">windowtitle</a>.
      * <br/>
      *
      * @since 2.5
@@ -108,6 +110,12 @@ public class TestJavadocJar
     @Parameter( alias = "javadocDirectory", defaultValue = "${basedir}/src/test/javadoc" )
     private File testJavadocDirectory;
 
+    /**
+     * @since 2.10
+     */
+    @Parameter( property = "maven.javadoc.testClassifier", defaultValue = "test-javadoc", required = true )
+    private String testClassifier;
+
     // ----------------------------------------------------------------------
     // Protected methods
     // ----------------------------------------------------------------------
@@ -115,7 +123,7 @@ public class TestJavadocJar
     @Override
     protected String getClassifier()
     {
-        return "test-javadoc";
+        return testClassifier;
     }
 
     // ----------------------------------------------------------------------
@@ -212,4 +220,10 @@ public class TestJavadocJar
     {
         return super.configureDependencySourceResolution( config ).withoutCompileSources().withTestSources();
     }
+
+    @Override
+    protected boolean isTest()
+    {
+        return true;
+    }
 }
