@@ -44,12 +44,12 @@ import java.util.ResourceBundle;
  * <a href="http://docs.oracle.com/javase/7/docs/technotes/guides/javadoc/">Javadoc Tool</a>.
  *
  * @author <a href="mailto:vincent.siveton@gmail.com">Vincent Siveton</a>
- * @version $Id: TestJavadocReport.java 1438083 2013-01-24 17:20:31Z olamy $
+ * @version $Id: TestJavadocReport.java 1666819 2015-03-15 18:32:20Z khmarbaise $
  * @since 2.3
  * @see <a href="http://docs.oracle.com/javase/7/docs/technotes/guides/javadoc/">Javadoc Tool</a>
- * @see <a href="http://docs.oracle.com/javase/1.4.2/docs/tooldocs/windows/javadoc.html#options">Javadoc Options </a>
+ * @see <a href="http://docs.oracle.com/javase/7/docs/technotes/tools/windows/javadoc.html#options">Javadoc Options </a>
  */
-@Mojo( name = "test-javadoc", requiresDependencyResolution = ResolutionScope.TEST, threadSafe = true)
+@Mojo( name = "test-javadoc", requiresDependencyResolution = ResolutionScope.TEST, threadSafe = true )
 @Execute( phase = LifecyclePhase.GENERATE_TEST_SOURCES )
 public class TestJavadocReport
     extends JavadocReport
@@ -61,7 +61,7 @@ public class TestJavadocReport
     /**
      * Specifies the Test title to be placed near the top of the overview summary file.
      * <br/>
-     * See <a href="http://docs.oracle.com/javase/1.4.2/docs/tooldocs/windows/javadoc.html#doctitle">doctitle</a>.
+     * See <a href="http://docs.oracle.com/javase/7/docs/technotes/tools/windows/javadoc.html#doctitle">doctitle</a>.
      * <br/>
      *
      * @since 2.5
@@ -76,7 +76,7 @@ public class TestJavadocReport
      * <br/>
      * <b>Note</b>: could be in conflict with &lt;nooverview/&gt;.
      * <br/>
-     * See <a href="http://docs.oracle.com/javase/1.4.2/docs/tooldocs/windows/javadoc.html#overview">overview</a>.
+     * See <a href="http://docs.oracle.com/javase/7/docs/technotes/tools/windows/javadoc.html#overview">overview</a>.
      * <br/>
      *
      * @since 2.5
@@ -88,7 +88,8 @@ public class TestJavadocReport
     /**
      * Specifies the Test title to be placed in the HTML title tag.
      * <br/>
-     * See <a href="http://docs.oracle.com/javase/1.4.2/docs/tooldocs/windows/javadoc.html#windowtitle">windowtitle</a>.
+     * See
+     * <a href="http://docs.oracle.com/javase/7/docs/technotes/tools/windows/javadoc.html#windowtitle">windowtitle</a>.
      * <br/>
      *
      * @since 2.5
@@ -353,4 +354,10 @@ public class TestJavadocReport
     {
         return super.configureDependencySourceResolution( config ).withoutCompileSources().withTestSources();
     }
+
+    @Override
+    protected boolean isTest()
+    {
+        return true;
+    }
 }
