@@ -46,7 +46,7 @@ import com.thoughtworks.qdox.model.JavaMethod;
 
 /**
  * @author <a href="mailto:vincent.siveton@gmail.com">Vincent Siveton</a>
- * @version $Id: FixJavadocMojoTest.java 1147437 2011-07-16 15:30:31Z rfscholte $
+ * @version $Id: FixJavadocMojoTest.java 1579989 2014-03-21 17:30:56Z aheritier $
  */
 public class FixJavadocMojoTest
     extends AbstractMojoTestCase
@@ -574,6 +574,35 @@ public class FixJavadocMojoTest
                 javaMethod, tag } );
         assertEquals( "     * @return A map configured.", tagJavadoc );
     }
+    
+    public void testInitParameters() 
+        throws Throwable
+    {
+        AbstractFixJavadocMojo mojoInstance = new FixJavadocMojo();
+        setVariableValueToObject( mojoInstance, "fixTags", "author, version, since, param, return, throws, link" );
+        setVariableValueToObject(mojoInstance, "defaultSince", "1.0");
+        setVariableValueToObject(mojoInstance, "level", "protected");
+        
+        PrivateAccessor.invoke( mojoInstance, "init", new Class[] { }, new String[] { } );
+        
+        String[] fixTags = (String[]) getVariableValueFromObject(mojoInstance, "fixTagsSplitted");
+        
+        assertEquals("author", fixTags[0]);
+        assertEquals("version", fixTags[1]);
+        assertEquals("since", fixTags[2]);
+        assertEquals("param", fixTags[3]);
+        assertEquals("return", fixTags[4]);
+        assertEquals("throws", fixTags[5]);
+        assertEquals("link", fixTags[6]);
+        assertEquals(7, fixTags.length);
+        
+        setVariableValueToObject( mojoInstance, "fixTags", "return, fake_value" );
+        PrivateAccessor.invoke( mojoInstance, "init", new Class[] { }, new String[] { } );
+        fixTags = (String[]) getVariableValueFromObject(mojoInstance, "fixTagsSplitted");
+        
+        assertEquals("return", fixTags[0]);
+        assertEquals(1, fixTags.length);
+    }
 
     // ----------------------------------------------------------------------
     // private methods
@@ -607,10 +636,8 @@ public class FixJavadocMojoTest
         File generatedDir = new File( testPomBasedir, "target/generated/fix/test" );
         assertTrue( generatedDir.exists() );
 
-        for ( int i = 0; i < clazzToCompare.length; i++ )
-        {
-            String className = clazzToCompare[i];
-            assertEquals( new File( expectedDir, className ), new File( generatedDir, className ) );
+        for (String className : clazzToCompare) {
+            assertEquals(new File(expectedDir, className), new File(generatedDir, className));
         }
     }
 
