@@ -20,14 +20,14 @@ package org.apache.maven.plugin.javadoc;
  */
 
 import org.apache.maven.plugin.testing.AbstractMojoTestCase;
-import org.codehaus.plexus.archiver.zip.ZipEntry;
-import org.codehaus.plexus.archiver.zip.ZipFile;
 import org.codehaus.plexus.util.FileUtils;
 
 import java.io.File;
 import java.util.Enumeration;
 import java.util.Set;
 import java.util.HashSet;
+import java.util.zip.ZipEntry;
+import java.util.zip.ZipFile;
 
 /**
  * @author <a href="mailto:oching@apache.org">Maria Odea Ching</a>
@@ -56,14 +56,28 @@ public class JavadocJarTest
         //validate contents of jar file
         ZipFile jar = new ZipFile( generatedFile );
         Set<String> set = new HashSet<String>();
-        for( Enumeration<ZipEntry> entries = jar.getEntries(); entries.hasMoreElements(); )
+        for( Enumeration<? extends ZipEntry> entries = jar.entries(); entries.hasMoreElements(); )
         {
             ZipEntry entry = entries.nextElement();
             set.add( entry.getName() );
         }
 
         assertTrue( set.contains( "stylesheet.css" ) );
-        assertTrue( set.contains( "resources/inherit.gif" ) || set.contains( "resources/background.gif" ) /* JDK7 */ );
+        float javadocVersion = (Float) getVariableValueFromObject( mojo, "fJavadocVersion" );
+        if ( Float.compare( javadocVersion, 1.7f ) < 0 )
+        {
+            assertTrue( set.contains( "resources/inherit.gif" ) );
+        }
+        else if ( Float.compare( javadocVersion, 1.8f ) < 0 )
+        {
+            assertTrue( set.contains( "resources/background.gif" ) /* JDK7 */);
+        }
+        else
+        {
+            // JDK8 has no resources anymore
+            assertFalse( set.contains( "resources" ) );
+        }
+
         assertTrue( set.contains( "javadocjar/def/package-use.html" ) );
         assertTrue( set.contains( "javadocjar/def/package-tree.html" ) );
         assertTrue( set.contains( "javadocjar/def/package-summary.html" ) );
@@ -107,4 +121,17 @@ public class JavadocJarTest
                                        "target/test/unit/javadocjar-invalid-destdir/target/javadocjar-invalid-destdir-javadoc.jar" );
         assertTrue( !FileUtils.fileExists( generatedFile.getAbsolutePath() ) );
     }
+
+    public void testContinueIfFailOnErrorIsFalse() throws Exception
+    {
+        File testPom =
+                new File( getBasedir(), "src/test/resources/unit/javadocjar-failonerror/javadocjar-failonerror-plugin-config.xml" );
+        JavadocJar mojo = (JavadocJar) lookupMojo( "jar", testPom );
+        mojo.execute();
+
+        //check if the javadoc jar file was generated
+        File generatedFile =
+                new File( getBasedir(), "target/test/unit/javadocjar-failonerror/target/javadocjar-failonerror-javadoc.jar" );
+        assertTrue( FileUtils.fileExists( generatedFile.getAbsolutePath() ) );
+    }
 }
