@@ -579,13 +579,13 @@ public class JavadocReportTest
         File app = new File( apidocs, "resources/test/App.html" );
         assertTrue( app.exists() );
         String content = readFile( app );
-        assertTrue( content.contains( "<img src=\"doc-files/maven-feather.png\" alt=\"Maven\"/>" ) );
+        assertTrue( content.contains( "<img src=\"doc-files/maven-feather.png\" alt=\"Maven\">" ) );
         assertTrue( new File( apidocs, "resources/test/doc-files/maven-feather.png" ).exists() );
 
         File app2 = new File( apidocs, "resources/test2/App2.html" );
         assertTrue( app2.exists() );
         content = readFile( app2 );
-        assertTrue( content.contains( "<img src=\"doc-files/maven-feather.png\" alt=\"Maven\"/>" ) );
+        assertTrue( content.contains( "<img src=\"doc-files/maven-feather.png\" alt=\"Maven\">" ) );
         assertFalse( new File( apidocs, "resources/test2/doc-files/maven-feather.png" ).exists() );
 
         // with excludes
@@ -598,13 +598,23 @@ public class JavadocReportTest
         app = new File( apidocs, "resources/test/App.html" );
         assertTrue( app.exists() );
         content = readFile( app );
-        assertTrue( content.contains( "<img src=\"doc-files/maven-feather.png\" alt=\"Maven\"/>" ) );
-        assertFalse( new File( apidocs, "resources/test/doc-files/maven-feather.png" ).exists() );
+        assertTrue( content.contains( "<img src=\"doc-files/maven-feather.png\" alt=\"Maven\">" ) );
+
+        float javadocVersion = (Float) getVariableValueFromObject( mojo, "fJavadocVersion" );
+        if( Float.compare( 1.8f, javadocVersion ) == 0 )
+        {
+            // https://bugs.openjdk.java.net/browse/JDK-8032205
+            assertTrue( "This bug appeared in JDK8 and was planned to be fixed in JDK9, see JDK-8032205", new File( apidocs, "resources/test/doc-files/maven-feather.png" ).exists() );
+        }
+        else
+        {
+            assertFalse( new File( apidocs, "resources/test/doc-files/maven-feather.png" ).exists() );
+        }
 
         app2 = new File( apidocs, "resources/test2/App2.html" );
         assertTrue( app2.exists() );
         content = readFile( app2 );
-        assertTrue( content.contains( "<img src=\"doc-files/maven-feather.png\" alt=\"Maven\"/>" ) );
+        assertTrue( content.contains( "<img src=\"doc-files/maven-feather.png\" alt=\"Maven\">" ) );
         assertTrue( new File( apidocs, "resources/test2/doc-files/maven-feather.png" ).exists() );
     }
 
@@ -636,7 +646,7 @@ public class JavadocReportTest
         File app = new File( apidocs, "resources/test/App.html" );
         assertTrue( app.exists() );
         overview = readFile( app );
-        assertTrue( overview.contains( "<img src=\"doc-files/maven-feather.png\" alt=\"Maven\"/>" ) );
+        assertTrue( overview.contains( "<img src=\"doc-files/maven-feather.png\" alt=\"Maven\">" ) );
         assertTrue( new File( apidocs, "resources/test/doc-files/maven-feather.png" ).exists() );
     }
 
@@ -652,7 +662,7 @@ public class JavadocReportTest
         JavadocReport mojo = (JavadocReport) lookupMojo( "javadoc", testPom );
         mojo.execute();
 
-        assertFalse( new File( getBasedir(), "target/test/unit/pom-test" ).exists() );
+        assertFalse( new File( getBasedir(), "target/test/unit/pom-test/target/site" ).exists() );
     }
 
     /**
@@ -673,7 +683,8 @@ public class JavadocReportTest
         assertTrue( readed.contains( ">To do something:</" ) );
         assertTrue( readed.contains( ">Generator Class:</" ) );
         assertTrue( readed.contains( ">Version:</" ) );
-        assertTrue( readed.toLowerCase().contains( "</dt>" + LINE_SEPARATOR + "  <dd>1.0</dd>" ) );
+        assertTrue( readed.toLowerCase().contains( "</dt>" + LINE_SEPARATOR + "  <dd>1.0</dd>" )
+            || readed.toLowerCase().contains( "</dt>" + LINE_SEPARATOR + "<dd>1.0</dd>" /* JDK 8 */) );
     }
 
     /**
@@ -805,7 +816,7 @@ public class JavadocReportTest
 
         // real proxy
         ProxyServer proxyServer = null;
-        AuthAsyncProxyServlet proxyServlet = null;
+        AuthAsyncProxyServlet proxyServlet;
         try
         {
             proxyServlet = new AuthAsyncProxyServlet();
